@@ -107,6 +107,8 @@ class DetectorNode(Node):
 
     async def set_model_version_mode(self, version_control_mode: str) -> None:
 
+        self.log.info('Setting model version mode to %s', version_control_mode)
+
         if version_control_mode == 'follow_loop':
             self.version_control = VersionMode.FollowLoop
         elif version_control_mode == 'pause':
@@ -215,7 +217,8 @@ class DetectorNode(Node):
                     camera_id=data.get('camera-id', None) or data.get('mac', None),
                     tags=data.get('tags', []),
                     source=data.get('source', None),
-                    autoupload=data.get('autoupload', None)
+                    autoupload=data.get('autoupload', None),
+                    creation_date=data.get('creation_date', None)
                 )
                 if det is None:
                     return {'error': 'no model loaded'}
@@ -324,13 +327,16 @@ class DetectorNode(Node):
                 with step_into(GLOBALS.data_folder):
                     model_symlink = 'model'
                     target_model_folder = f'models/{self.target_model.version}'
-                    shutil.rmtree(target_model_folder, ignore_errors=True)
-                    os.makedirs(target_model_folder)
-
-                    await self.data_exchanger.download_model(target_model_folder,
-                                                             Context(organization=self.organization,
-                                                                     project=self.project),
-                                                             self.target_model.id, self.detector_logic.model_format)
+                    if not os.path.exists(target_model_folder):
+                        os.makedirs(target_model_folder)
+                        await self.data_exchanger.download_model(target_model_folder,
+                                                                 Context(organization=self.organization,
+                                                                         project=self.project),
+                                                                 self.target_model.id,
+                                                                 self.detector_logic.model_format)
+                        self.log.info('Downloaded model %s', self.target_model.version)
+                    else:
+                        self.log.info('No need to download model %s (already exists)', self.target_model.version)
                     try:
                         os.unlink(model_symlink)
                         os.remove(model_symlink)
@@ -339,7 +345,12 @@ class DetectorNode(Node):
                     os.symlink(target_model_folder, model_symlink)
                     self.log.info('Updated symlink for model to %s', os.readlink(model_symlink))
 
-                    self.detector_logic.load_model()
+                    try:
+                        self.detector_logic.load_model()
+                    except Exception:
+                        self.log.exception('Could not load model, will retry download on next check')
+                        shutil.rmtree(target_model_folder, ignore_errors=True)
+                        return
                     try:
                         await self.sync_status_with_learning_loop()
                     except Exception:
